@@ -3,16 +3,19 @@ from typing import Any, Callable, Tuple
 
 from fastapi import HTTPException, Request
 
+__version__ = "1.0.2"
+
 
 def _parse_key_operator(key: str) -> Tuple[str, str]:
-    match = re.match(r'([^\[]+)(?:\[([^\]]+)\])?', key)
+    match = re.match(r"([^\[]+)(?:\[([^\]]+)\])?", key)
     key, operator = match.groups()
 
     if operator is None:
-        operator = 'eq'
+        operator = "eq"
 
     return key, operator
 
+
 def query_conditions(field: str, factory: Callable[[str], Any]):
     def inner(request: Request):
         conditions = {}
